@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_nan.h 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id: gmt_nan.h 19625 2018-01-19 01:21:57Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -45,11 +45,15 @@
 #	define gmt_M_make_dnan(x) (x = DBL_MAX)
 #	define gmt_M_is_fnan(x) ((x) == FLT_MAX)
 #	define gmt_M_is_dnan(x) ((x) == DBL_MAX)
+#	define gmt_M_is_finf(x) ((x) == FLT_MAX)
+#	define gmt_M_is_dinf(x) ((x) == DBL_MAX)
 #else
 #	define gmt_M_make_fnan(x) (x = (float) NAN)
 #	define gmt_M_make_dnan(x) (x = NAN)
 #	define gmt_M_is_fnan isnan
 #	define gmt_M_is_dnan isnan
+#	define gmt_M_is_finf isinf
+#	define gmt_M_is_dinf isinf
 #endif
 
 #endif /* _GMT_NAN_H */
