@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmt_project.h 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id: gmt_project.h 20055 2018-04-22 00:27:09Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -51,8 +51,8 @@ EXTERN_MSC double gmtmap_lat_swap_quick (struct GMT_CTRL *GMT, double lat, doubl
 /*! Macros returns true if the two coordinates are lon/lat; way should be GMT_IN or GMT_OUT */
 #define gmt_M_x_is_lon(C,way) (C->current.io.col_type[way][GMT_X] == GMT_IS_LON)
 #define gmt_M_y_is_lon(C,way) (C->current.io.col_type[way][GMT_Y] == GMT_IS_LON)
+#define gmt_M_x_is_lat(C,way) (C->current.io.col_type[way][GMT_X] == GMT_IS_LAT)
 #define gmt_M_y_is_lat(C,way) (C->current.io.col_type[way][GMT_Y] == GMT_IS_LAT)
-#define gmt_M_x_is_lat(C,way) (C->current.io.col_type[way][GMT_Y] == GMT_IS_LAT)
 #define gmt_M_is_geographic(C,way) (gmt_M_x_is_lon(C,way) && gmt_M_y_is_lat(C,way))
 
 #define GMT_N_PROJECTIONS	29	/* Total number of projections in GMT */
