@@ -1,5 +1,5 @@
 /*
- *	$Id: gmtregress.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id: gmtregress.c 20071 2018-04-29 00:01:29Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -533,7 +533,7 @@ GMT_LOCAL double gmt_demeaning (struct GMT_CTRL *GMT, double *X, double *Y, doub
 			w_xy = w[GMT_X][i] * w[GMT_Y][i];
 			alpha_i = sqrt (w_xy);
 			if (w[GMT_Z]) corr_i = w[GMT_Z][i];
-			W[i] = w_xy / (w[GMT_X][i] + par[GMTREGRESS_SLOPE] * par[GMTREGRESS_SLOPE] * w[GMT_Y][i] - 2 * par[GMTREGRESS_SLOPE] * corr_i * alpha_i);
+			W[i] = (w_xy > 0.0) ? w_xy / (w[GMT_X][i] + par[GMTREGRESS_SLOPE] * par[GMTREGRESS_SLOPE] * w[GMT_Y][i] - 2 * par[GMTREGRESS_SLOPE] * corr_i * alpha_i) : 0.0;
 			if (alpha) alpha[i] = alpha_i;
 		}
 		/*  Step 4: Compute weighted X_mean, Y_mean, then U, V, and beta */
@@ -666,13 +666,12 @@ GMT_LOCAL double LSxy_regress1D_basic (struct GMT_CTRL *GMT, double *x, double *
 GMT_LOCAL double LSRMA_regress1D (struct GMT_CTRL *GMT, double *x, double *y, double *w[], uint64_t n, double *par) {
 	/* Basic LS RMA orthogonal regression with no weights [Reference?] */
 	uint64_t k;
-	double mx, sx, my, sy, scale;
+	double sx, sy, scale;
 	double *U = gmt_M_memory (GMT, NULL, n, double), *V = gmt_M_memory (GMT, NULL, n, double), *W = gmt_M_memory (GMT, NULL, n, double);
 	gmt_M_memset (par, GMTREGRESS_NPAR, double);
 	(void)gmt_demeaning (GMT, x, y, w, n, par, U, V, W, NULL, NULL);
-	mx = gmt_mean_and_std (GMT, U, n, &sx);
-	my = gmt_mean_and_std (GMT, V, n, &sy);
-	GMT_Report (GMT->parent, GMT_MSG_DEBUG, "mx and my should be zero: %g %g\n", mx, my);
+	sx = gmt_std_weighted (GMT, U, w[GMT_X], 0.0, n);
+	sy = gmt_std_weighted (GMT, V, w[GMT_Y], 0.0, n);
 	par[GMTREGRESS_SLOPE] = sy / sx;
 	par[GMTREGRESS_ICEPT] = par[GMTREGRESS_YMEAN] - par[GMTREGRESS_SLOPE] * par[GMTREGRESS_XMEAN];
 	par[GMTREGRESS_ANGLE] = atand (par[GMTREGRESS_SLOPE]);
