@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: gmtselect.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id: gmtselect.c 20205 2018-06-02 22:37:34Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -669,7 +669,7 @@ int GMT_gmtselect (void *V_API, int mode, void *args) {
 	else	/* Cartesian data */
 		gmt_init_distaz (GMT, 'R', 0, GMT_MAP_DIST);	/* Compute r-squared instead of r to avoid hypot  */
 	
-	gmt_disable_ih_opts (GMT);	/* Do not want any -i to affect the reading from -C,-F,-L files */
+	gmt_disable_bhi_opts (GMT);	/* Do not want any -b -h -i to affect the reading from -C,-F,-L files */
 
 	if (Ctrl->C.active) { 	/* Initialize point structure used in test for proximity to points [use Ctrl->C.dist ]*/
 		if ((Cin = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_POINT, GMT_IO_ASCII, NULL, Ctrl->C.file, NULL)) == NULL) {
@@ -773,7 +773,7 @@ int GMT_gmtselect (void *V_API, int mode, void *args) {
 		}
 	}
 	
-	gmt_reenable_ih_opts (GMT);	/* Recover settings provided by user (if -i was used at all) */
+	gmt_reenable_bhi_opts (GMT);	/* Recover settings provided by user (if -b -h -i were used at all) */
 
 	/* Specify input and output expected columns */
 	if ((error = gmt_set_cols (GMT, GMT_IN,  0)) != 0) Return (error);
@@ -890,7 +890,12 @@ int GMT_gmtselect (void *V_API, int mode, void *args) {
 
 		if (Ctrl->G.active) {	/* Check if we are in/out-side mask cell */
 			unsigned int row, col;
-			inside = !gmt_row_col_out_of_bounds (GMT, in, G->header, &row, &col);
+			if (gmt_M_y_is_outside (GMT, in[GMT_Y], G->header->wesn[YLO], G->header->wesn[YHI]) ||	/* Outside y-range */
+				gmt_x_is_outside (GMT, &in[GMT_X], G->header->wesn[XLO], G->header->wesn[XHI])) {	/* Outside x-range */
+				inside = false;	/* Outside both y- and x-range (or periodic longitude) for this grid */
+			}
+			else
+				inside = !gmt_row_col_out_of_bounds (GMT, in, G->header, &row, &col);
 			if (inside) {	/* Inside -R so check the node value */
 				uint64_t node = gmt_M_ijp (G->header, row, col);
 				inside = !(gmt_M_is_fnan (G->data[node]) || G->data[node] == 0);
