@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *    $Id: grdblend.c 19521 2017-12-27 22:38:24Z pwessel $
+ *    $Id: grdblend.c 20251 2018-06-18 03:57:16Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -776,7 +776,7 @@ int GMT_grdblend (void *V_API, int mode, void *args) {
 					switch (Ctrl->C.mode) {
 						case BLEND_FIRST: if (m) continue; break;	/* Already set */
 						case BLEND_UPPER: if (m && blend[k].z[kk] <= z[col]) continue; break;	/* Already has a higher value; else set below */
-						case BLEND_LOWER: if (m && blend[k].z[kk] >- z[col]) continue; break;	/* Already has a lower value; else set below */
+						case BLEND_LOWER: if (m && blend[k].z[kk] >= z[col]) continue; break;	/* Already has a lower value; else set below */
 						/* Last case BLEND_LAST is always true in that we always update z[col] */
 					}
 					z[col] = blend[k].z[kk];					/* Just pick this grid's value */
