@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: pscontour.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id: pscontour.c 19717 2018-02-05 05:18:54Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -524,7 +524,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSCONTOUR_CTRL *Ctrl, struct G
 				}
 				else if (opt->arg[0] == '-')
 					Ctrl->A.mode = 1;	/* Turn off all labels */
-				else if (opt->arg[0] == '+') {
+				else if (opt->arg[0] == '+' && (isdigit(opt->arg[1]) || strchr ("-+.", opt->arg[1]))) {
 					Ctrl->A.single_cont = atof (&opt->arg[1]);
 					Ctrl->contour.annot = true;
 				}
@@ -547,7 +547,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSCONTOUR_CTRL *Ctrl, struct G
 					gmt_M_str_free (Ctrl->C.file);
 					Ctrl->C.file = strdup (opt->arg);
 				}
-				else if (opt->arg[0] == '+')
+				else if (opt->arg[0] == '+' && (isdigit(opt->arg[1]) || strchr ("-+.", opt->arg[1])))
 					Ctrl->C.single_cont = atof (&opt->arg[1]);
 				else
 					Ctrl->C.interval = atof (opt->arg);
@@ -649,7 +649,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSCONTOUR_CTRL *Ctrl, struct G
 			case 'W':	/* Sets pen attributes */
 				Ctrl->W.active = true;
 				k = reset = 0;
-				if (strchr ("-+", opt->arg[0])) {	/* Definitively old-style args */
+				if (opt->arg[0] == '-' || (opt->arg[0] == '+' && opt->arg[1] != 'c')) {	/* Definitively old-style args */
 					if (opt->arg[k] == '+') Ctrl->W.cptmode = 1, k++;
 					if (opt->arg[k] == '-') Ctrl->W.cptmode = 3, k++;
 					j = (opt->arg[k] == 'a' || opt->arg[k] == 'c') ? k+1 : k;
@@ -661,12 +661,14 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSCONTOUR_CTRL *Ctrl, struct G
 							case 'f': Ctrl->W.cptmode = 2; break;
 							default:  Ctrl->W.cptmode = 3; break;
 						}
+						if (!strncmp (&c[2], "lf", 2U) || !strncmp (&c[2], "fl", 2U))	/* Catch any odd +clf or +cfl modifiers */
+							Ctrl->W.cptmode = 3;
 						c[0] = 0;	/* Temporarily chop of */
 						reset = 1;
 					}
 					j = (opt->arg[0] == 'a' || opt->arg[0] == 'c') ? k+1 : k;
 				}
-				if (j == k) {	/* Set both */
+				if (j == k && opt->arg[j]) {	/* Set both */
 					if (gmt_getpen (GMT, &opt->arg[j], &Ctrl->W.pen[0])) {
 						gmt_pen_syntax (GMT, 'W', " ", 0);
 						n_errors++;
@@ -674,7 +676,7 @@ GMT_LOCAL int parse (struct GMT_CTRL *GMT, struct PSCONTOUR_CTRL *Ctrl, struct G
 					else
 						Ctrl->W.pen[1] = Ctrl->W.pen[0];
 				}
-				else {	/* Gave a or c.  Because the user may say -Wcyan we must prevent this from being seen as -Wc and color yan! */
+				else if (opt->arg[j]) {	/* Gave a or c.  Because the user may say -Wcyan we must prevent this from being seen as -Wc and color yan! */
 					/* Get the argument following a or c and up to first comma, slash (or to the end) */
 					n = k+1;
 					while (!(opt->arg[n] == ',' || opt->arg[n] == '/' || opt->arg[n] == '\0')) n++;
@@ -1328,10 +1330,9 @@ int GMT_pscontour (void *V_API, int mode, void *args) {
 			Ctrl->contour.line_pen = Ctrl->W.pen[id];	/* Load current pen into contour structure */
 
 			if (Ctrl->W.cpt_effect) {
-				if (Ctrl->W.cptmode & 1) {	/* Override pen color according to CPT */
-					gmt_get_rgb_from_z (GMT, P, cont[c].val, rgb);
+				gmt_get_rgb_from_z (GMT, P, cont[c].val, rgb);
+				if (Ctrl->W.cptmode & 1)	/* Override pen color according to CPT */
 					gmt_M_rgb_copy (&Ctrl->contour.line_pen.rgb, rgb);
-				}
 				if (Ctrl->W.cptmode & 2)	/* Override label color according to CPT */
 					gmt_M_rgb_copy (&Ctrl->contour.font_label.fill.rgb, rgb);
 			}
