@@ -1,5 +1,5 @@
 /*--------------------------------------------------------------------
- *	$Id: sample1d.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id: sample1d.c 20205 2018-06-02 22:37:34Z pwessel $
  *
  *	Copyright (c) 1991-2018 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
@@ -339,11 +339,11 @@ int GMT_sample1d (void *V_API, int mode, void *args) {
 		struct GMT_DATASET *Cin = NULL;
 		gmt_init_io_columns (GMT, GMT_IN);	/* Reset any effects of -i */
 		
-		gmt_disable_ih_opts (GMT);	/* Do not want any -i to affect the reading from -C,-F,-L files */
+		gmt_disable_bhi_opts (GMT);	/* Do not want any -b -h -i to affect the reading from -C,-F,-L files */
 		if ((Cin = GMT_Read_Data (API, GMT_IS_DATASET, GMT_IS_FILE, GMT_IS_NONE, GMT_READ_NORMAL, NULL, Ctrl->N.file, NULL)) == NULL) {
 			Return (API->error);
 		}
-		gmt_reenable_ih_opts (GMT);	/* Recover settings provided by user (if -i was used at all) */
+		gmt_reenable_bhi_opts (GMT);	/* Recover settings provided by user (if -b -h -i were used at all) */
 		T = Cin->table[0];	/* Since we only have one table here */
 		t_supplied_out = gmt_M_memory (GMT, NULL, Cin->table[0]->n_records, double);
 		for (seg = 0; seg < T->n_segments; seg++) {
