@@ -1,5 +1,5 @@
 /*-----------------------------------------------------------------
- *	$Id: x2sys_put.c 19521 2017-12-27 22:38:24Z pwessel $
+ *	$Id: x2sys_put.c 20312 2018-06-28 02:05:50Z pwessel $
  *
  *      Copyright (c) 1999-2018 by P. Wessel
  *      See LICENSE.TXT file for copying and redistribution conditions.
@@ -195,7 +195,7 @@ int GMT_x2sys_put (void *V_API, int mode, void *args) {
 
 	char track[GMT_LEN64] = {""}, line[GMT_BUFSIZ] = {""};
 	char track_file[GMT_BUFSIZ] = {""}, index_file[GMT_BUFSIZ] = {""}, old_track_file[GMT_BUFSIZ] = {""}, old_index_file[GMT_BUFSIZ] = {""};
-	char track_path[] = {""}, index_path[GMT_BUFSIZ] = {""}, old_track_path[GMT_BUFSIZ] = {""}, old_index_path[GMT_BUFSIZ] = {""};
+	char track_path[GMT_BUFSIZ] = {""}, index_path[GMT_BUFSIZ] = {""}, old_track_path[GMT_BUFSIZ] = {""}, old_index_path[GMT_BUFSIZ] = {""};
 
 	int error = 0, k;
 	bool found_it, skip;
@@ -361,32 +361,49 @@ int GMT_x2sys_put (void *V_API, int mode, void *args) {
 	x2sys_path (GMT, old_track_file, old_track_path);
 	x2sys_path (GMT, old_index_file, old_index_path);
 
-	if (gmt_remove_file (GMT, old_track_path)) {	/* First delete old file */
-		x2sys_end (GMT, s);
-		Return (GMT_RUNTIME_ERROR);
+	/* First deal with the possible existence of a current track/index pair and possibly an old track/index pair of fails */
+	
+	if (!access (old_track_path, F_OK)) {	/* First delete old file */
+		GMT_Report (API, GMT_MSG_DEBUG, "Found old track file %s.  Try to remove it.\n", old_track_path);
+		if (gmt_remove_file (GMT, old_track_path)) {	/* First delete old track file */
+			GMT_Report (API, GMT_MSG_DEBUG, "Unable to delete %s.  Aborting!\n", old_track_path);
+			x2sys_end (GMT, s);
+			Return (GMT_RUNTIME_ERROR);
+		}
 	}
-	if (gmt_rename_file (GMT, track_path, old_track_path)) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Rename failed for %s\t%s. Aborting %d!\n", track_path, old_track_path, i);
-		x2sys_end (GMT, s);
-		Return (GMT_RUNTIME_ERROR);
+	if (!access (track_path, F_OK)) {	/* Next rename current file (if it exists) to the old file */
+		GMT_Report (API, GMT_MSG_DEBUG, "Found current track file %s.  Try to rename it.\n", track_path);
+		if (gmt_rename_file (GMT, track_path, old_track_path)) {
+			GMT_Report (API, GMT_MSG_NORMAL, "Rename failed for %s -> %s. Aborting!\n", track_path, old_track_path);
+			x2sys_end (GMT, s);
+			Return (GMT_RUNTIME_ERROR);
+		}
 	}
-	if (gmt_remove_file (GMT, old_index_path)) {	/* First delete old file */
-		x2sys_end (GMT, s);
-		Return (GMT_RUNTIME_ERROR);
+	if (!access (old_index_path, F_OK)) {	/* First delete old file */
+		GMT_Report (API, GMT_MSG_DEBUG, "Found old index file %s.  Try to remove it.\n", old_index_path);
+		if (gmt_remove_file (GMT, old_index_path)) {	/* First delete old index file */
+			x2sys_end (GMT, s);
+			Return (GMT_RUNTIME_ERROR);
+		}
 	}
-	if (gmt_rename_file (GMT, index_path, old_index_path)) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Rename failed for %s. Aborts!\n", index_path);
-		x2sys_end (GMT, s);
-		Return (GMT_RUNTIME_ERROR);
+	if (!access (index_path, F_OK)) {	/* Next rename current file (if it exists) to the old file */
+		GMT_Report (API, GMT_MSG_DEBUG, "Found current index file %s.  Try to rename it\n", index_path);
+		if (gmt_rename_file (GMT, index_path, old_index_path)) {
+			GMT_Report (API, GMT_MSG_NORMAL, "Rename failed for %s. Aborts!\n", index_path);
+			x2sys_end (GMT, s);
+			Return (GMT_RUNTIME_ERROR);
+		}
 	}
 
+	/* Now we can create new files since any existing files have been removed or renamed */
+
 	if ((ftrack = fopen (track_path, "w")) == NULL) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Failed to create %s. Aborts!\n", track_path);
+		GMT_Report (API, GMT_MSG_NORMAL, "Failed to create track data base %s. Aborts!\n", track_path);
 		x2sys_end (GMT, s);
 		Return (GMT_ERROR_ON_FOPEN);
 	}
 	if ((fbin = fopen (index_path, "wb")) == NULL) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Failed to create %s. Aborts!\n", index_path);
+		GMT_Report (API, GMT_MSG_NORMAL, "Failed to create index data base %s. Aborts!\n", index_path);
 		fclose (ftrack);
 		x2sys_end (GMT, s);
 		Return (GMT_ERROR_ON_FOPEN);
@@ -397,7 +414,7 @@ int GMT_x2sys_put (void *V_API, int mode, void *args) {
 
 	fclose (ftrack);
 	if (chmod (track_file, (mode_t)S_RDONLY))
-		GMT_Report (API, GMT_MSG_NORMAL, "Warning: Failed to change file %s to read-only!\n", track_file);
+		GMT_Report (API, GMT_MSG_NORMAL, "Warning: Failed to change track file %s to read-only!\n", track_file);
 
 	for (index = 0; index < B.nm_bin; index++) {
 		if (B.base[index].n_tracks == 0) continue;
@@ -427,7 +444,7 @@ int GMT_x2sys_put (void *V_API, int mode, void *args) {
 	}
 	fclose (fbin);
 	if (chmod (index_file, (mode_t)S_RDONLY))
-		GMT_Report (API, GMT_MSG_NORMAL, "Warning: Failed to change file %s to read-only!\n", index_file);
+		GMT_Report (API, GMT_MSG_NORMAL, "Warning: Failed to change index file %s to read-only!\n", index_file);
 
 	GMT_Report (API, GMT_MSG_VERBOSE, "completed successfully\n");
 
